import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:sigmob_plugin/flutter_sigmob_reward.dart';
import 'package:sigmob_plugin/sigmob.dart';

class RewardVideoAdPage extends StatefulWidget {
  @override
  _RewardVideoAdPageState createState() => _RewardVideoAdPageState();
}

class _RewardVideoAdPageState extends State<RewardVideoAdPage> {
  String _placementId1 = 'eb2abf76101';
  String _placementId2 = 'eb2abf76101';

  @override
  void initState() {
    super.initState();
    _setCallback();
  }

  void _setCallback() async {
    FlutterSigmobRewardVideoAd.instance.setAdListener(AdListener(
      onAdLoadSuccess: (String placementId) {
        _showMessage('onAdLoadSuccess: $placementId');
      },
      onAdLoadError: (String placementId, String message, int code) {
        _showMessage(
            'onAdLoadError: $placementId, message: $message, code: $code');
      },
      onAdClosed: (String placementId, bool isCompeltedView) {
        _showMessage(
            'onAdClosed: $placementId, isCompeltedView: $isCompeltedView');
      },
      onAdPlayStart: (String placementId) {
        _showMessage('onAdPlayStart: $placementId');
      },
      onAdPlayEnd: (String placementId) {
        _showMessage('onAdPlayEnd: $placementId');
      },
      onAdClicked: (String placementId) {
        _showMessage('onAdClicked: $placementId');
      },
      onAdServerDidFail: (String placementId) {
        _showMessage('onAdServerDidFail: $placementId');
      },
      onAdServerDidSuccess: (String placementId) {
        _showMessage('onAdServerDidSuccess: $placementId');
      },
    ));
  }

  void _loadAd(String placementId) {
    var request = SigmobAdRequest(placementId);
    FlutterSigmobRewardVideoAd.instance.loadAd(request);
  }

  void _playAd(String placementId) async {
    bool isReady =
        await FlutterSigmobRewardVideoAd.instance.isReady(placementId);
    if (isReady) {
      FlutterSigmobRewardVideoAd.instance.playAd(placementId);
    } else {
      _showMessage('$placementId is not ready!');
    }
  }

  void _showMessage(String msg) {
    Fluttertoast.showToast(msg: msg);
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        appBar: AppBar(
          title: const Text('激励视频广告'),
        ),
        body: Column(
          children: <Widget>[
            Padding(
              padding: EdgeInsets.all(10),
              child: Row(
                children: <Widget>[
                  Expanded(
                    flex: 2,
                    child: RaisedButton(
                      child: Text('LoadAd: $_placementId1'),
                      onPressed: () {
                        _loadAd(_placementId1);
                      },
                    ),
                  ),
                  SizedBox(
                    width: 20,
                  ),
                  Expanded(
                    flex: 1,
                    child: RaisedButton(
                      child: Text('播放广告'),
                      onPressed: () {
                        _playAd(_placementId1);
                      },
                    ),
                  ),
                ],
              ),
            ),
            Padding(
              padding: EdgeInsets.fromLTRB(10, 0, 10, 10),
              child: Row(
                children: <Widget>[
                  Expanded(
                    flex: 2,
                    child: RaisedButton(
                      child: Text('LoadAd: $_placementId2'),
                      onPressed: () {
                        _loadAd(_placementId2);
                      },
                    ),
                  ),
                  SizedBox(
                    width: 20,
                  ),
                  Expanded(
                    flex: 1,
                    child: RaisedButton(
                      child: Text('播放广告'),
                      onPressed: () {
                        _playAd(_placementId2);
                      },
                    ),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
