//
//  FlutterSigmobRewardVideoPlugin.m
//  fluttersigmob
//
//  Created by Codi on 2020/7/17.
//

#import "FlutterSigmobRewardVideoPlugin.h"
#import <Flutter/Flutter.h>
#import <WindSDK/WindSDK.h>
#import "FlutterSigmobEventPlugin.h"
#import "FlutterSigmobUtil.h"

@interface FlutterSigmobRewardVideoPlugin()<WindRewardedVideoAdDelegate>
@property (nonatomic, strong) FlutterSigmobEventPlugin *eventPlugin;
@end

@implementation FlutterSigmobRewardVideoPlugin

- (instancetype)initWithEventPlugin:(FlutterSigmobEventPlugin *)eventPlugin {
    self = [super init];
    if (self) {
        self.eventPlugin = eventPlugin;
    }
    return self;
}



/*
 * 获取广告位的广告状态
 */
- (void)isReadyMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSLog(@"%s", __func__);
    NSString *placementId = [call.arguments objectForKey:@"placementId"];
    BOOL isReady = [[WindRewardedVideoAd sharedInstance] isReady:placementId];
    result(@(isReady));
}



/*
 * 播放广告
 */
- (void)playAdMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSLog(@"%s", __func__);
    NSString *placementId = [call.arguments objectForKey:@"placementId"];
    UIViewController *currentVC = [FlutterSigmobUtil getCurrentViewController];
    NSLog(@"currentVC = %@", currentVC);
    [[WindRewardedVideoAd sharedInstance] playAd:currentVC withPlacementId:placementId options:nil error:nil];
    result(nil);
}




/*
 * 加载广告
 */
- (void)loadAdMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSLog(@"%s", __func__);
    NSString *placementId = [call.arguments objectForKey:@"placementId"];
    NSString *userId = [call.arguments objectForKey:@"userId"];
    NSDictionary *options = [call.arguments objectForKey:@"options"];
    WindAdRequest *request = [WindAdRequest request];
    request.placementId = placementId;
    request.userId = userId;
    request.options = options;
    //设置delegate
    [[WindRewardedVideoAd sharedInstance] setDelegate:self];
    //执行加载广告
    [[WindRewardedVideoAd sharedInstance] loadRequest:request withPlacementId:placementId];
    result(nil);
}





#pragma mark - WindRewardedVideoAdDelegate

/**
 激励视频广告物料加载成功（此时isReady=YES）
 广告是否ready请以当前回调为准
 
 @param placementId 广告位Id
 */
- (void)onVideoAdLoadSuccess:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdLoadSuccess)
                                   });
    }
    
}


/**
 激励视频广告加载时发生错误
 
 @param error 发生错误时会有相应的code和message
 @param placementId 广告位Id
 */
- (void)onVideoError:(NSError *)error placementId:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"msg": error.localizedDescription,
            @"code": @(error.code),
            @"event":@(SigmobCallbackError)
                                   });
    }
}


/**
 激励视频广告关闭
 
 @param info WindRewardInfo里面包含一次广告关闭中的是否完整观看等参数
 @param placementId 广告位Id
 */
- (void)onVideoAdClosedWithInfo:(WindRewardInfo *)info placementId:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"isCompeltedView": @(info.isCompeltedView),
            @"event":@(SigmobCallbackAdClosed)
                                   });
    }
}



/**
 激励视频广告开始播放
 
 @param placementId 广告位Id
 */
- (void)onVideoAdPlayStart:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdPlayStart)
                                   });
    }
}



/**
 激励视频广告发生点击
 
 @param placementId 广告位Id
 */
- (void)onVideoAdClicked:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdClicked)
                                   });
    }
}



/**
 激励视频广告调用播放时发生错误
 
 @param error 发生错误时会有相应的code和message
 @param placementId 广告位Id
 */
- (void)onVideoAdPlayError:(NSError *)error placementId:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"msg": error.localizedDescription,
            @"code": @(error.code),
            @"event":@(SigmobCallbackAdPlayError)
                                   });
    }
}

/**
 激励视频广告视频播关闭
 
 @param placementId 广告位Id
 */
- (void)onVideoAdPlayEnd:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdPlayEnd)
                                   });
    }
}


/**
 激励视频广告AdServer返回广告(表示渠道有广告填充)
 
 @param placementId 广告位Id
 */
- (void)onVideoAdServerDidSuccess:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdServerDidSuccess)
                                   });
    }
}


/**
 激励视频广告AdServer无广告返回(表示渠道无广告填充)
 
 @param placementId 广告位Id
 */
- (void)onVideoAdServerDidFail:(NSString *)placementId {
    NSLog(@"%s", __func__);
    if (self.eventPlugin.eventSink) {
        self.eventPlugin.eventSink(@{
            @"placementId": placementId,
            @"event":@(SigmobCallbackAdServerDidFail)
                                   });
    }
}

@end
