#import "SigmobPlugin.h"
#import <WindSDK/WindSDK.h>
#import "FlutterSigmobRewardVideoPlugin.h"
#import "FlutterSigmobInterstitialAdPlugin.h"
#import "FlutterSigmobEventPlugin.h"

@interface SigmobPlugin()

@property (nonatomic, strong) FlutterSigmobRewardVideoPlugin *rewardVideoAdPlugin;
@property (nonatomic, strong) FlutterSigmobInterstitialAdPlugin *interstitialAdPlugin;

@end


@implementation SigmobPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"sigmob_plugin"
            binaryMessenger:[registrar messenger]];
    
    
    FlutterSigmobEventPlugin *rewardEventPlugin = [[FlutterSigmobEventPlugin alloc] initChannelWithName:@"flutter.sigmob.reward.channel" binaryMessenger:[registrar messenger]];
    FlutterSigmobRewardVideoPlugin *rewardVideoAdPlugin = [[FlutterSigmobRewardVideoPlugin alloc] initWithEventPlugin:rewardEventPlugin];

    FlutterSigmobEventPlugin *fullscreenEventPlugin = [[FlutterSigmobEventPlugin alloc] initChannelWithName:@"flutter.sigmob.interstitial.channel" binaryMessenger:[registrar messenger]];
    FlutterSigmobInterstitialAdPlugin *fullscreenVideoAdPlugin = [[FlutterSigmobInterstitialAdPlugin alloc] initWithEventPlugin:fullscreenEventPlugin];
    
    SigmobPlugin* instance = [[SigmobPlugin alloc] init];
    
    instance.rewardVideoAdPlugin = rewardVideoAdPlugin;
    instance.interstitialAdPlugin = fullscreenVideoAdPlugin;
    
    [registrar addMethodCallDelegate:instance channel:channel];
}


- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *func = [NSString stringWithFormat:@"%@MethodCall:result:", call.method];
    NSNumber *adType = [call.arguments objectForKey:@"adType"];
    SEL selector = NSSelectorFromString(func);
    NSLog(@"func = %@", func);
    BOOL isImplementSel = NO;
    id target = self;
    if (adType == nil) {
        isImplementSel = [self respondsToSelector:selector];
    }else if (adType.intValue == 0) {
        target = self.rewardVideoAdPlugin;
        isImplementSel = [self.rewardVideoAdPlugin respondsToSelector:selector];
    }else if (adType.intValue == 1) {
        target = self.interstitialAdPlugin;
        isImplementSel = [self.interstitialAdPlugin respondsToSelector:selector];
    }
    NSString *args = [self convertToJsonData:call.arguments];
    NSLog(@"[isImplementSel = %d, target = %@, func = %@, argus = %@]", isImplementSel, target, func, args);
    if (isImplementSel) {
        ((void (*)(id, SEL, id, id))[target methodForSelector:selector])(target, selector, call, result);
    }else {
        result(FlutterMethodNotImplemented);
    }
}


/*
 * 获取sdk的版本号
 */
- (void)getSdkVersionMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *version = [WindAds sdkVersion];
    result(version);
}

- (void)initWithAppIdMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *appId = [call.arguments objectForKey:@"appId"];
    NSString *appKey = [call.arguments objectForKey:@"appKey"];
    BOOL usedMediation = [[call.arguments objectForKey:@"usedMediation"] boolValue];
    WindAdOptions *options = [[WindAdOptions alloc] initWithAppId:appId appKey:appKey usedMediation:usedMediation];
    [WindAds startWithOptions:options];
}



- (NSString *)convertToJsonData:(NSDictionary*)dict {
    if (dict == nil) {
        return @"no args";
    }
    NSError*error;
    NSData *jsonData = [NSJSONSerialization dataWithJSONObject:dict options:NSJSONWritingPrettyPrinted error:&error];
    NSString*jsonString;
    if(!jsonData) {
        NSLog(@"convertToJsonData: %@",error);
    }else{
        jsonString = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
    }
    return jsonString;
}




@end
