import 'dart:async';

import 'package:flutter/services.dart';
import 'package:sigmob_plugin/sigmob.dart';
import 'package:sigmob_plugin/sigmob_enum.dart';


class FlutterSigmobRewardVideoAd {

  MethodChannel _channel;
  AdListener _adListener;


  // 工厂模式
  factory FlutterSigmobRewardVideoAd() =>_getInstance();
  static FlutterSigmobRewardVideoAd get instance => _getInstance();
  static FlutterSigmobRewardVideoAd _instance;
  FlutterSigmobRewardVideoAd._internal() {
    // 初始化
    _initEvent();
  }
  static FlutterSigmobRewardVideoAd _getInstance() {
    if (_instance == null) {
      _instance = new FlutterSigmobRewardVideoAd._internal();
    }
    return _instance;
  }

  _initEvent() {
    print('init event.....');
    _eventChannelFor()
        .receiveBroadcastStream()
        .listen(_eventListener, onError: _errorListener);
  }

  EventChannel _eventChannelFor() {
    return EventChannel('flutter.sigmob.reward.channel');
  }

  _eventListener(dynamic event) {
    Map<dynamic, dynamic> args = event;
    String placementId = args['placementId'];
    var et = args['event'];
    SigmobCallback callbackEvent = SigmobCallback.values[et];
    switch(callbackEvent) {
      case SigmobCallback.AdServerDidSuccess:{
          _adServerDidSuccess(placementId);
        }
        break;
      case SigmobCallback.AdServerDidFail:{
        _adServerDidFail(placementId);
      }
        break;
      case SigmobCallback.AdLoadSuccess:{
        _adLoadSuccess(placementId);
      }
        break;
      case SigmobCallback.AdPlayStart:{
        _adPlayStart(placementId);
      }
        break;
      case SigmobCallback.AdPlayEnd:{
        _adPlayEnd(placementId);
      }
        break;
      case SigmobCallback.AdClicked:{
        _adClicked(placementId);
      }
        break;
      case SigmobCallback.AdClosed:{
        bool isCompeltedView = args['isCompeltedView'];
        _adClosed(placementId, isCompeltedView);
      }
        break;
      case SigmobCallback.AdError:{
        String message = args['msg'];
        num code = args['code'];
        _adError(placementId, message, code);
      }
        break;
      case SigmobCallback.AdPlayError:{
        String message = args['msg'];
        num code = args['code'];
        _adPlayError(placementId, message, code);
      }
        break;
    }
    print(event);
  }

  _errorListener(dynamic obj) {

  }


  Future<void> setChannel(MethodChannel channel) async {
    this._channel = channel;
  }

  void setAdListener(AdListener adListener) {
    _adListener = adListener;
  }


  Future<bool> isReady (String placementId) async {
    var args = <String, dynamic>{'placementId': placementId, 'adType': AdType.rewardVideo.index};
    bool isReady = await _channel.invokeMethod('isReady', args);
    return isReady;
  }

  Future<void> loadAd(SigmobAdRequest request) async {
    var args = request.toJson();
    args['adType'] = AdType.rewardVideo.index;
    await _channel.invokeMethod('loadAd', args);
  }


  Future<void> playAd(String placementId, {Map<String, String> options}) async {
    var args = Map();
    args['adType'] = AdType.rewardVideo.index;
    args['placementId'] = placementId;
    args['options'] = options;
    await _channel.invokeMethod('playAd', args);
  }

  _adServerDidSuccess(String placementId) {
    if(this._adListener != null && this._adListener.onAdServerDidSuccess != null) {
      this._adListener.onAdServerDidSuccess(placementId);
    }
  }

  _adServerDidFail(String placementId) {
    if(this._adListener != null && this._adListener.onAdServerDidFail != null) {
      this._adListener.onAdServerDidFail(placementId);
    }
  }
  _adLoadSuccess(String placementId ) {
    if(this._adListener != null && this._adListener.onAdLoadSuccess != null) {
      this._adListener.onAdLoadSuccess(placementId);
    }
  }
  _adPlayStart(String placementId) {
    if(this._adListener != null && this._adListener.onAdPlayStart != null) {
      this._adListener.onAdPlayStart(placementId);
    }
  }
  _adPlayEnd(String placementId) {
    if(this._adListener != null && this._adListener.onAdPlayEnd != null) {
      this._adListener.onAdPlayEnd(placementId);
    }
  }
  _adClicked(String placementId) {
    if(this._adListener != null && this._adListener.onAdClicked != null) {
      this._adListener.onAdClicked(placementId);
    }
  }

  _adClosed(String placementId, bool isCompeltedView) {
    if(this._adListener != null && this._adListener.onAdClosed != null) {
      this._adListener.onAdClosed(placementId, isCompeltedView);
    }
  }

  _adError(String placementId, String message, num code) {
    if(this._adListener != null && this._adListener.onAdLoadError != null) {
      this._adListener.onAdLoadError(placementId, message, code.toInt());
    }
  }

  _adPlayError(String placementId, String message, num code) {
    if(this._adListener != null && this._adListener.onAdPlayError != null) {
      this._adListener.onAdPlayError(placementId, message, code.toInt());
    }
  }
}
