import 'dart:core';

import 'package:flutter/cupertino.dart';


typedef OnAdServerDidSuccess = void Function(String placementId);
typedef OnAdServerDidFail = void Function(String placementId);
typedef OnAdLoadSuccess = void Function(String placementId);
typedef OnAdPlayStart = void Function(String placementId);
typedef OnAdPlayEnd = void Function(String placementId);
typedef OnAdClicked = void Function(String placementId);
typedef OnAdClosed = void Function(String placementId, bool isCompeltedView);
typedef OnAdLoadError = void Function(String placementId, String message, int code);
typedef OnAdPlayError = void Function(String placementId, String message, int code);


class AdListener {
  OnAdServerDidSuccess onAdServerDidSuccess;
  OnAdServerDidFail onAdServerDidFail;
  OnAdLoadSuccess onAdLoadSuccess;
  OnAdPlayStart onAdPlayStart;
  OnAdPlayEnd onAdPlayEnd;
  OnAdClicked onAdClicked;
  OnAdClosed onAdClosed;
  OnAdLoadError onAdLoadError;
  OnAdPlayError onAdPlayError;

  AdListener({
    @required this.onAdLoadSuccess,
    @required this.onAdClosed,
    this.onAdServerDidSuccess,
    this.onAdServerDidFail,
    this.onAdPlayStart,
    this.onAdPlayEnd,
    this.onAdClicked,
    this.onAdLoadError,
    this.onAdPlayError
  });

  @override
  noSuchMethod(Invocation invocation) {
    print(invocation.memberName);
    return super.noSuchMethod(invocation);
  }

}

class SigmobAdRequest {
  /// 用户ID
  String userId;

  /// 广告位id，从sigmob平台获取
  String placementId;

  /// 扩展参数
  Map<String, String> options;

  SigmobAdRequest(this.placementId, {this.userId, this.options});

  Map toJson() {
    Map map = new Map();
    if(this.userId != null && this.userId.isNotEmpty) {
      map["userId"] = this.userId;
    }
    if (this.placementId != null && this.placementId.isNotEmpty) {
      map["placementId"] = this.placementId;
    }
    if (this.options != null) {
      map["options"] = this.options;
    }
    return map;
  }
}


